@@ -319,8 +319,8 @@ class Card(_Verify):
                                  % _digits_NFSC)
 
     # FSC commentary card string which must contain printable ASCII characters.
-    _ascii_text = r'[ -~]*$'
-    _comment_FSC_RE = re.compile(_ascii_text)
+    # Note: \Z matches the end of the string without allowing newlines
+    _ascii_text_re = re.compile(r'[ -~]*\Z')
 
     # Checks for a valid value/comment string.  It returns a match object
     # for a valid value/comment string.
@@ -568,27 +568,33 @@ class Card(_Verify):
                 "Floating point %r values are not allowed in FITS headers." %
                 value)
         elif isinstance(value, unicode):
-            try:
-                # Any string value must be encodable as ASCII
-                value.encode('ascii')
-            except UnicodeEncodeError:
+            m = self._ascii_text_re.match(value)
+            if not m:
                 raise ValueError(
-                    'FITS header values must contain standard ASCII '
+                    'FITS header values must contain standard printable ASCII '
                     'characters; %r contains characters not representable in '
-                    'ASCII.' % value)
+                    'ASCII or non-printable characters.' % value)
         elif isinstance(value, bytes):
             # Allow str, but only if they can be decoded to ASCII text; note
             # this is not even allowed on Python 3 since the `bytes` type is
             # not included in `six.string_types`.  Presently we simply don't
             # allow bytes to be assigned to headers, as doing so would too
             # easily mask potential user error
+            valid = True
             try:
-                value.decode('ascii')
+                text_value = value.decode('ascii')
             except UnicodeDecodeError:
+                valid = False
+            else:
+                # Check against the printable characters regexp as well
+                m = self._ascii_text_re.match(text_value)
+                valid = m is not None
+
+            if not valid:
                 raise ValueError(
-                    'FITS header values must contain standard ASCII '
+                    'FITS header values must contain standard printable ASCII '
                     'characters; %r contains characters/bytes that do not '
-                    'represent characters in ASCII.' % value)
+                    'represent printable characters in ASCII.' % value)
         elif isinstance(value, np.bool_):
             value = bool(value)
 
@@ -683,14 +689,13 @@ class Card(_Verify):
             comment = ''
 
         if isinstance(comment, unicode):
-            try:
-                # Any string value must be encodable as ASCII
-                comment.encode('ascii')
-            except UnicodeEncodeError:
+            m = self._ascii_text_re.match(comment)
+            if not m:
                 raise ValueError(
-                    'FITS header comments must contain standard ASCII '
-                    'characters; %r contains characters not representable in '
-                    'ASCII.' % comment)
+                    'FITS header comments must contain standard printable '
+                    'ASCII characters; %r contains characters not '
+                    'representable in ASCII or non-printable characters.' %
+                    comment)
 
         oldcomment = self._comment
         if oldcomment is None:
@@ -1321,24 +1326,37 @@ class Card(_Verify):
 
         # verify the value, it may be fixable
         keyword, valuecomment = self._split()
-        m = self._value_FSC_RE.match(valuecomment)
-        if not (m or self.keyword in self._commentary_keywords):
-            errs.append(self.run_option(
-                option,
-                err_text='Card %r is not FITS standard (invalid value '
-                         'string: %s).' % (self.keyword, valuecomment),
-                fix_text=fix_text,
-                fix=self._fix_value))
+        if self.keyword in self._commentary_keywords:
+            # For commentary keywords all that needs to be ensured is that it
+            # contains only printable ASCII characters
+            if not self._ascii_text_re.match(valuecomment):
+                errs.append(self.run_option(
+                    option,
+                    err_text='Unprintable string %r; commentary cards may '
+                             'only contain printable ASCII characters' %
+                             valuecomment,
+                    fixable=False))
+        else:
+            m = self._value_FSC_RE.match(valuecomment)
+            if not m:
+                errs.append(self.run_option(
+                    option,
+                    err_text='Card %r is not FITS standard (invalid value '
+                             'string: %s).' % (self.keyword, valuecomment),
+                    fix_text=fix_text,
+                    fix=self._fix_value))
 
         # verify the comment (string), it is never fixable
         m = self._value_NFSC_RE.match(valuecomment)
         if m is not None:
             comment = m.group('comm')
             if comment is not None:
-                if not self._comment_FSC_RE.match(comment):
+                if not self._ascii_text_re.match(comment):
                     errs.append(self.run_option(
                         option,
-                        err_text='Unprintable string %r' % comment,
+                        err_text='Unprintable string %r; header comments may '
+                                 'only contain printable ASCII characters' %
+                                 comment,
                         fixable=False))
 
         return errs
