@@ -9,6 +9,11 @@ import warnings
 
 from collections import defaultdict
 
+try:
+    from itertools import zip_longest
+except ImportError:
+    from itertools import izip_longest as zip_longest
+
 from pyfits.card import Card, CardList, BLANK_CARD, KEYWORD_LENGTH, _pad
 from pyfits.file import _File
 from pyfits.util import (BLOCK_SIZE, deprecated, isiterable, encode_ascii,
@@ -2095,13 +2100,22 @@ class _CardAccessor(object):
         return iter(self._header._cards)
 
     def __eq__(self, other):
-        if isiterable(other):
-            for a, b in itertools.izip(self, other):
-                if a != b:
-                    return False
+        # If the `other` item is a scalar we will still treat it as equal if
+        # this _CardAccessor only contains one item
+        if not isiterable(other) or isinstance(other, basestring):
+            if len(self) == 1:
+                other = [other]
             else:
-                return True
-        return False
+                return False
+
+        for a, b in zip_longest(self, other):
+            if a != b:
+                return False
+        else:
+            return True
+
+    def __ne__(self, other):
+        return not (self == other)
 
     def __getitem__(self, item):
         if isinstance(item, slice) or self._header._haswildcard(item):
