@@ -402,6 +402,39 @@ class TestCore(PyfitsTestCase):
         assert_raises(TypeError, setattr, h1, 'ver', 'FOO')
         assert_raises(TypeError, setattr, h1, 'level', 'BAR')
 
+    def test_consecutive_writeto(self):
+        """
+        Regression test for an issue where calling writeto twice on the same
+        HDUList could write a corrupted file.
+
+        https://github.com/spacetelescope/PyFITS/issues/40 is actually a
+        particular instance of this problem, though isn't unique to sys.stdout.
+        """
+
+        with fits.open(self.data('test0.fits')) as hdul1:
+            # Add a bunch of header keywords so that the data will be forced to
+            # new offsets within the file:
+            for idx in range(40):
+                hdul1[1].header['TEST%d' % idx] = 'test'
+
+            hdul1.writeto(self.temp('test1.fits'))
+            hdul1.writeto(self.temp('test2.fits'))
+
+            # Open a second handle to the original file and compare it to hdul1
+            # (We only compare part of the one header that was modified)
+            # Compare also with the second writeto output
+            with fits.open(self.data('test0.fits')) as hdul2:
+                with fits.open(self.temp('test2.fits')) as hdul3:
+                    for hdul in (hdul1, hdul3):
+                        for idx, hdus in enumerate(zip(hdul1, hdul)):
+                            hdu1, hdu2 = hdus
+                            if idx != 1:
+                                assert hdu1.header == hdu2.header
+                            else:
+                                assert (hdu1.header ==
+                                        hdu2.header[:len(hdu1.header)])
+                            assert np.all(hdu1.data == hdu2.data)
+
 
 class TestConvenienceFunctions(PyfitsTestCase):
     def test_writeto(self):
