@@ -1,4 +1,4 @@
-/* $Id: compressionmodule.c 2341 2013-11-09 20:17:35Z stsci_embray $ 
+/* $Id$ 
 */
 
 /* "compression module */
@@ -749,7 +749,6 @@ void init_output_buffer(PyObject* hdu, void** buf, size_t* bufsize) {
         *bufsize += ((size_t) (IOBUFLEN - (*bufsize % IOBUFLEN)));
     }
 
-    // TODO: Add error handling here
     *buf = calloc(*bufsize, sizeof(char));
 fail:
     Py_XDECREF(header);
@@ -900,16 +899,20 @@ PyObject* compression_compress_hdu(PyObject* self, PyObject* args)
     // We just need to get the compressed bytes and PyFITS will handle the
     // writing of them.
     init_output_buffer(hdu, &outbuf, &outbufsize);
+    if (outbuf == NULL) {
+        return NULL;
+    }
+
     open_from_hdu(&fileptr, &outbuf, &outbufsize, hdu, &columns);
     if (PyErr_Occurred()) {
-        return NULL;
+        goto fail;
     }
 
     Fptr = fileptr->Fptr;
 
     bitpix_to_datatypes(Fptr->zbitpix, &datatype, &npdatatype);
     if (PyErr_Occurred()) {
-        return NULL;
+        goto fail;
     }
 
     indata = (PyArrayObject*) PyObject_GetAttrString(hdu, "data");
@@ -949,7 +952,15 @@ PyObject* compression_compress_hdu(PyObject* self, PyObject* args)
     // Leaves refcount of tmp untouched, so its refcount should remain as 1
     retval = Py_BuildValue("KN", heapsize, tmp);
 
+    goto cleanup;
+
 fail:
+    if (outbuf != NULL) {
+        // At this point outbuf should never not be NULL, but in principle
+        // buggy code somewhere in CFITSIO or Numpy could set it to NULL
+        free(outbuf);
+    }
+cleanup:
     if (columns != NULL) {
         PyMem_Free(columns);
         Fptr->tableptr = NULL;
